==> PyInq-0.1.0.zip: PyInq-0.1.0/examples/suite_structure.py <==
from pyinq.tags import *

@BeforeModule
def setupModule():
	print "set up module"

@AfterModule
def teardownModule():
	print "tear down module"

@BeforeSuite
def setupGlobalSuite():
	print "setting up global suite"

@BeforeSuite(suite="suite1")
def setupSuite1():
	print "setup suite 1"

@AfterSuite(suite="suite1")
def teardownSuite1():
	print "tear down suite 1"

@TestClass
class Class1:
	@BeforeClass
	def setup():
		print "setup Class1" 
	
	@BeforeSuite(suite="suite4")
	def setupSuite4():
		print "setup suite 4"

	@Test(suite="suite1")
	def test1():
		print "test1 in Class1"
	
	@Test(suite="suite2")
	def test2():
		print "test2 in Class1"
	
	@Test(suite="suite3")
	def test3():
		print "test3 in Class1"
	
	@Test
	def test4():
		print "test4 in Class1"
	
	@Test(suite="suite4")
	def suite_fixture_test1():
		print "test1 in suite4"

	@AfterClass
	def teardown():
		print "teardown Class1"

@TestClass
class Class2:
	@Before
	def setup():
		print "setup test in Class2" 

	@Test(suite="suite1")
	def test5():
		print "test5 in Class2"
	
	@Test(suite="suite2")
	def test6():
		print "test6 in Class2"
	
	@Test(suite="suite3")
	def test7():
		print "test7 in Class2"

	@Test
	def test8():
		print "test8 in Class2"

	@Test(suite="suite4")
	def suite_fixture_test2():
		print "test2 in suite4"

	@After
	def teardown():
		print "teardown test in Class2"

@AfterSuite(suite="suite2")
def teardownSuite2():
	print "tear down suite 2"

@AfterSuite
def teardownGlobalSuite():
	print "tearing down global suite"

==> PyInq-0.2.0.zip: PyInq-0.2.0/examples/suite_structure.py <==
from pyinq.tags import *

@beforeModule
def setupModule():
	print "set up module"

@afterModule
def teardownModule():
	print "tear down module"

@beforeSuite
def setupGlobalSuite():
	print "setting up global suite"

@beforeSuite(suite="suite1")
def setupSuite1():
	print "setup suite 1"

@afterSuite(suite="suite1")
def teardownSuite1():
	print "tear down suite 1"

@testClass
class Class1:
	@beforeClass
	def setup():
		print "setup Class1" 
	
	@beforeSuite(suite="suite4")
	def setupSuite4():
		print "setup suite 4"

	@test(suite="suite1")
	def test1():
		print "test1 in Class1"
	
	@test(suite="suite2")
	def test2():
		print "test2 in Class1"
	
	@test(suite="suite3")
	def test3():
		print "test3 in Class1"
	
	@test
	def test4():
		print "test4 in Class1"
	
	@test(suite="suite4")
	def suite_fixture_test1():
		print "test1 in suite4"

	@afterClass
	def teardown():
		print "teardown Class1"

@testClass
class Class2:
	@before
	def setup():
		print "setup test in Class2" 

	@test(suite="suite1")
	def test5():
		print "test5 in Class2"
	
	@test(suite="suite2")
	def test6():
		print "test6 in Class2"
	
	@test(suite="suite3")
	def test7():
		print "test7 in Class2"

	@test
	def test8():
		print "test8 in Class2"

	@test(suite="suite4")
	def suite_fixture_test2():
		print "test2 in suite4"

	@after
	def teardown():
		print "teardown test in Class2"

@afterSuite(suite="suite2")
def teardownSuite2():
	print "tear down suite 2"

@afterSuite
def teardownGlobalSuite():
	print "tearing down global suite"
